===============================
Clustering of (mis)orientations
===============================

These guides show how to segment crystallographic map points into clusters based on the
(mis)orientation distances. This functionality was why ``orix`` was initially written.

.. nbgallery::
    :hidden:

    clustering_across_fundamental_region_boundaries.ipynb
    clustering_orientations.ipynb
    clustering_misorientations.ipynb
